==> zio-aws-iot1clickdevices_2.13-5.17.123.2-sources.jar: zio/aws/iot1clickdevices/model/ClaimDevicesByClaimCodeRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ClaimDevicesByClaimCodeRequest(claimCode: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest = {
    import ClaimDevicesByClaimCodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
      .builder()
      .claimCode(__string.unwrap(claimCode): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
      .wrap(buildAwsValue())
}
object ClaimDevicesByClaimCodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest =
      zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest(claimCode)
    def claimCode: __string
    def getClaimCode: ZIO[Any, Nothing, __string] = ZIO.succeed(claimCode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
  ) extends zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest.ReadOnly {
    override val claimCode: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.claimCode())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
  ): zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.203.1-sources.jar: zio/aws/iot1clickdevices/model/ClaimDevicesByClaimCodeRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ClaimDevicesByClaimCodeRequest(claimCode: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest = {
    import ClaimDevicesByClaimCodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
      .builder()
      .claimCode(claimCode: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
      .wrap(buildAwsValue())
}
object ClaimDevicesByClaimCodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest =
      zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest(claimCode)
    def claimCode: __string
    def getClaimCode: ZIO[Any, Nothing, __string] = ZIO.succeed(claimCode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
  ) extends zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest.ReadOnly {
    override val claimCode: __string = impl.claimCode(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest
  ): zio.aws.iot1clickdevices.model.ClaimDevicesByClaimCodeRequest.ReadOnly =
    new Wrapper(impl)
}
